import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { parse } from 'query-string';

/**
 * Detector classes obtain list of user's locales. It can be from browser, url, cookies, storage, ... whatever you want
 * Get locales method always return array of locales.
 */
class Detector {}

/**
 * This detector load locales from GET parameters. The value should be locale separated list.
 */

class UrlDetector extends Detector {
  /**
   * Constructor
   *
   * @param {string} parameter - Which parameter to look for.
   * @param {Location} location - window.location is used on default
   */
  constructor(parameter, location = window.location) {
    super();

    _defineProperty(this, "location", void 0);

    _defineProperty(this, "parameter", void 0);

    this.location = location;
    this.parameter = parameter;
  }
  /**
   * Get list of locales from browser url.
   *
   * @returns {Array<string>} list of locales
   */


  getLocales() {
    const locales = parse(this.location.search)[this.parameter] || null;

    if (typeof locales === 'string') {
      return locales.split(',');
    }

    return [];
  }

}

export default UrlDetector;
