'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var _defineProperty = _interopDefault(require('@babel/runtime/helpers/defineProperty'));

/**
 * Transformer are used to change format of locale (eg. convert it to uppercase), create fallbacks or delete invalid items.
 */
class Transformer {}

/**
 * This transformer allows you to append default locale.
 */

class DefaultLocaleTransformer extends Transformer {
  /**
   * Constructor.
   *
   * @param {string} defaultLocale - set default locale
   */
  constructor(defaultLocale) {
    super();

    _defineProperty(this, "defaultLocale", void 0);

    this.defaultLocale = defaultLocale;
  }
  /**
   * Add default locale to end of array
   *
   * @param {Array<string>} locales - list of locales
   * @returns {Array<string>} locales with default
   */


  transform(locales) {
    const transformedLocales = [...locales.map(locale => {
      const splitedLocale = locale.split('-');
      return splitedLocale.map((value, index) => {
        const localeGenerator = [];

        for (let i = 0; i <= index; i++) {
          localeGenerator.push(splitedLocale[i]);
        }

        return localeGenerator.join('-');
      }).reverse();
    }).reduce((a, b) => a.concat(b), []), ...[this.defaultLocale]]; // slice locales that comes after default locale

    return transformedLocales.slice(0, transformedLocales.indexOf(this.defaultLocale) + 1);
  }

}

module.exports = DefaultLocaleTransformer;
