import _defineProperty from '@babel/runtime/helpers/defineProperty';

/**
 * Transformer are used to change format of locale (eg. convert it to uppercase), create fallbacks or delete invalid items.
 */
class Transformer {}

/**
 * This transformer convert locales to standard IETF language tag.
 */

class IETFTransformer extends Transformer {
  /**
   * Constructor.
   *
   * @param {string} localeSeparator - how is locales parts separated
   */
  constructor(localeSeparator = '-') {
    super();

    _defineProperty(this, "localeSeparator", void 0);

    this.localeSeparator = localeSeparator;
  }
  /**
   * Convert locales to standard IETF language tag.
   *
   * @param {Array<string>} locales - list of locales
   * @returns {Array<string>} list of transformed locales
   */


  transform(locales) {
    return locales.map(locale => {
      return locale.split(this.localeSeparator).map((value, index) => {
        return index === 1 ? value.toUpperCase() : value.toLowerCase();
      }).join('-');
    });
  }

}

export default IETFTransformer;
